==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/kasten/controllers/document/info/bytearraymodeliodevice.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYMODELIODEVICE_H
#define BYTEARRAYMODELIODEVICE_H

// Okteta
#include <okteta/address.h>
// Qt
#include <QIODevice>

namespace Okteta {

class AbstractByteArrayModel;

class ByteArrayModelIoDevice : public QIODevice
{
    Q_OBJECT

public:
    explicit ByteArrayModelIoDevice(AbstractByteArrayModel* byteArrayModel, QObject* parent = nullptr);
    ByteArrayModelIoDevice() = delete;

    ~ByteArrayModelIoDevice() override;

public: // QIODevice API
    qint64 size() const override;
    bool canReadLine() const override;

    bool open(OpenMode openMode) override;
    bool seek(qint64 pos) override;

protected:
    qint64 readData(char* data, qint64 maxlength) override;
    qint64 writeData(const char* data, qint64 length) override;

protected:
    AbstractByteArrayModel* mByteArrayModel;
    Address mReadOffset = 0;
};

}

#endif

==> okteta_15.12.3.orig.tar.xz: okteta-15.12.3/kasten/controllers/document/info/bytearraymodeliodevice.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYMODELIODEVICE_H
#define BYTEARRAYMODELIODEVICE_H

// Okteta
#include <okteta/address.h>
// Qt
#include <QIODevice>


namespace Okteta
{

class AbstractByteArrayModel;


class  ByteArrayModelIoDevice : public QIODevice
{
  Q_OBJECT

  public:
    explicit ByteArrayModelIoDevice( AbstractByteArrayModel* byteArrayModel, QObject* parent = 0 );
    virtual ~ByteArrayModelIoDevice();

  public: // QIODevice API
    virtual qint64 size() const;
    virtual bool canReadLine() const;

    virtual bool open( OpenMode openMode );
    virtual bool seek( qint64 pos );

  protected:
    virtual qint64 readData( char* data, qint64 maxlength );
    virtual qint64 writeData( const char* data, qint64 length );

  protected:
    AbstractByteArrayModel* mByteArrayModel;
    Address mReadOffset;
};

}

#endif
